pub struct TimeoutConfigMetadata {
pub fast_round_ms: Option<String>,
pub base_timeout_ms: String,
pub timeout_increment_ms: String,
pub fallback_duration_ms: String,
}Expand description
Timeout configuration metadata for GraphQL.
Fields
fast_round_ms: Option<String>The duration of the fast round in milliseconds.
base_timeout_ms: StringThe duration of the first single-leader and all multi-leader rounds in milliseconds.
timeout_increment_ms: StringThe duration by which the timeout increases after each single-leader round in milliseconds.
fallback_duration_ms: StringThe age of an incoming tracked or protected message after which validators start transitioning to fallback mode, in milliseconds.
Implementations
Sourceimpl TimeoutConfigMetadata
impl TimeoutConfigMetadata
pub async fn fast_round_ms(&self, ctx: &Context<'_>) -> Result<&Option<String>>
pub async fn base_timeout_ms(&self, ctx: &Context<'_>) -> Result<&String>
pub async fn timeout_increment_ms(&self, ctx: &Context<'_>) -> Result<&String>
pub async fn fallback_duration_ms(&self, ctx: &Context<'_>) -> Result<&String>