pub struct MessageBundle {
pub height: BlockHeight,
pub timestamp: Timestamp,
pub certificate_hash: CryptoHash,
pub transaction_index: u32,
pub messages: Vec<PostedMessage>,
}Expand description
A set of messages from a single block, for a single destination.
Fields
height: BlockHeightThe block height.
timestamp: TimestampThe block’s timestamp.
certificate_hash: CryptoHashThe confirmed block certificate hash.
transaction_index: u32The index of the transaction in the block that is sending this bundle.
messages: Vec<PostedMessage>The relevant messages.
Implementations
Sourceimpl MessageBundle
impl MessageBundle
pub async fn height(&self, ctx: &Context<'_>) -> Result<&BlockHeight>
pub async fn timestamp(&self, ctx: &Context<'_>) -> Result<&Timestamp>
pub async fn certificate_hash(&self, ctx: &Context<'_>) -> Result<&CryptoHash>
pub async fn transaction_index(&self, ctx: &Context<'_>) -> Result<&u32>
pub async fn messages(&self, ctx: &Context<'_>) -> Result<&Vec<PostedMessage>>
Sourceimpl MessageBundle
impl MessageBundle
Sourcepub fn estimated_size(&self) -> usize
pub fn estimated_size(&self) -> usize
Returns a rough estimate of the serialized size in bytes, for chunking.
Sourceimpl MessageBundle
impl MessageBundle
Sourcepub fn is_skippable(&self) -> bool
pub fn is_skippable(&self) -> bool
Returns whether all messages in this bundle can be skipped.
Sourcepub fn is_protected(&self) -> bool
pub fn is_protected(&self) -> bool
Returns whether any message in this bundle is protected.