pub struct PostedMessage {
pub authenticated_signer: Option<AccountOwner>,
pub grant: Amount,
pub refund_grant_to: Option<Account>,
pub kind: MessageKind,
pub index: u32,
pub message: Message,
}Expand description
A message together with kind, authentication and grant information.
Fields
authenticated_signer: Option<AccountOwner>The user authentication carried by the message, if any.
grant: AmountA grant to pay for the message execution.
refund_grant_to: Option<Account>Where to send a refund for the unused part of the grant after execution, if any.
kind: MessageKindThe kind of message being sent.
index: u32The index of the message in the sending block.
message: MessageThe message itself.
Implementations
Sourceimpl PostedMessage
impl PostedMessage
Sourcepub fn estimated_size(&self) -> usize
pub fn estimated_size(&self) -> usize
Returns a rough estimate of the serialized size in bytes.
Sourceimpl PostedMessage
impl PostedMessage
pub async fn authenticated_signer( &self, ctx: &Context<'_>, ) -> Result<&Option<AccountOwner>>
pub async fn grant(&self, ctx: &Context<'_>) -> Result<&Amount>
pub async fn refund_grant_to( &self, ctx: &Context<'_>, ) -> Result<&Option<Account>>
pub async fn kind(&self, ctx: &Context<'_>) -> Result<&MessageKind>
pub async fn index(&self, ctx: &Context<'_>) -> Result<&u32>
pub async fn message(&self, ctx: &Context<'_>) -> Result<&Message>
Sourceimpl PostedMessage
impl PostedMessage
Sourcepub fn is_skippable(&self) -> bool
pub fn is_skippable(&self) -> bool
Returns whether this message can be skipped.
Sourcepub fn is_protected(&self) -> bool
pub fn is_protected(&self) -> bool
Returns whether this message is protected.
Sourcepub fn is_tracked(&self) -> bool
pub fn is_tracked(&self) -> bool
Returns whether this message is tracked.
Sourcepub fn is_bouncing(&self) -> bool
pub fn is_bouncing(&self) -> bool
Returns whether this message is bouncing.