pub struct BlockBody {
pub transactions: Vec<Transaction>,
pub messages: Vec<Vec<OutgoingMessage>>,
pub previous_message_blocks: BTreeMap<ChainId, (CryptoHash, BlockHeight)>,
pub previous_event_blocks: BTreeMap<StreamId, (CryptoHash, BlockHeight)>,
pub oracle_responses: Vec<Vec<OracleResponse>>,
pub events: Vec<Vec<Event>>,
pub blobs: Vec<Vec<Blob>>,
pub operation_results: Vec<OperationResult>,
}Expand description
The body of a block containing all the data included in the block.
Fields
transactions: Vec<Transaction>The transactions to execute in this block. Each transaction can be either incoming messages or an operation.
messages: Vec<Vec<OutgoingMessage>>The list of outgoing messages for each transaction.
previous_message_blocks: BTreeMap<ChainId, (CryptoHash, BlockHeight)>The hashes and heights of previous blocks that sent messages to the same recipients.
previous_event_blocks: BTreeMap<StreamId, (CryptoHash, BlockHeight)>The hashes and heights of previous blocks that published events to the same channels.
oracle_responses: Vec<Vec<OracleResponse>>The record of oracle responses for each transaction.
events: Vec<Vec<Event>>The list of events produced by each transaction.
blobs: Vec<Vec<Blob>>The list of blobs produced by each transaction.
operation_results: Vec<OperationResult>The execution result for each operation.
Implementations
Sourceimpl BlockBody
impl BlockBody
pub async fn messages( &self, ctx: &Context<'_>, ) -> Result<&Vec<Vec<OutgoingMessage>>>
pub async fn previous_message_blocks( &self, ctx: &Context<'_>, ) -> Result<&BTreeMap<ChainId, (CryptoHash, BlockHeight)>>
pub async fn previous_event_blocks( &self, ctx: &Context<'_>, ) -> Result<&BTreeMap<StreamId, (CryptoHash, BlockHeight)>>
pub async fn oracle_responses( &self, ctx: &Context<'_>, ) -> Result<&Vec<Vec<OracleResponse>>>
pub async fn events(&self, ctx: &Context<'_>) -> Result<&Vec<Vec<Event>>>
pub async fn blobs(&self, ctx: &Context<'_>) -> Result<&Vec<Vec<Blob>>>
pub async fn operation_results( &self, ctx: &Context<'_>, ) -> Result<&Vec<OperationResult>>
Sourceimpl BlockBody
impl BlockBody
Sourcepub fn operations(&self) -> impl Iterator<Item = &Operation>
pub fn operations(&self) -> impl Iterator<Item = &Operation>
Returns all operations in this block body.
Sourcepub fn incoming_bundles(&self) -> impl Iterator<Item = &IncomingBundle>
pub fn incoming_bundles(&self) -> impl Iterator<Item = &IncomingBundle>
Returns all incoming bundles in this block body.