pub enum BundleFailurePolicy {
Abort,
AutoRetry {
max_failures: u32,
},
}Expand description
Policy for handling message bundle execution failures.
Variants
Abort
Abort block execution on any bundle failure. The proposal is never modified.
AutoRetry
Automatically handle failing bundles with checkpointing and retry.
This policy is intended for use by clients when preparing proposals. It modifies the proposal by discarding or rejecting bundles that fail to execute:
- For limit errors (block too large, fuel exceeded, etc.): discard the bundle so it can be retried in a later block, unless it’s the first transaction (in which case it’s inherently too large and gets rejected).
- For non-limit errors: reject the bundle (triggering bounced messages).
- After
max_failuresdiscarded bundles, discard all remaining message bundles.